@@ -1,12 +1,15 @@
 /*
  * modsclean.c
  *
+ * Copyright (c) Chris Putnam 2004-2017
+ *
+ * Program and source code released under the GPL version 2
+ *
  */
 #include <stdio.h>
 #include <stdlib.h>
 #include "bibutils.h"
-#include "modsin.h"
-#include "modsout.h"
+#include "bibformats.h"
 #include "tomods.h"
 #include "bibprog.h"
 
