@@ -1,11 +1,14 @@
+/*
+ * tomods.h
+ *
+ * Copyright (c) Chris Putnam 2012-2017
+ *
+ * Program and source code released under the GPL version 2
+ *
+ */
 #ifndef TOMODS_H
 #define TOMODS_H
 
-#if 0
-extern void tomods( int argc, char *argv[], int readmode, int writemode,
-		char *progname, char *help1, char *help2 );
-#endif
-
 extern void tomods_processargs( int *argc, char *argv[], param *p,
         char *help1, char *help2 );
 
