@@ -1,16 +1,15 @@
 /*
  * xml2ads.c
  *
- * Copyright (c) Chris Putnam 2007-2010
+ * Copyright (c) Chris Putnam 2007-2017
  *
- * Program and source code released under the GPL
+ * Program and source code released under the GPL version 2
  *
  */
 #include <stdio.h>
 #include <stdlib.h>
 #include "bibutils.h"
-#include "modsin.h"
-#include "adsout.h"
+#include "bibformats.h"
 #include "args.h"
 #include "bibprog.h"
 
@@ -24,14 +23,14 @@ help( char *progname )
 
 	fprintf(stderr,"usage: %s xml_file > adsabs_file\n\n",progname);
         fprintf(stderr,"  xml_file can be replaced with file list or omitted to use as a filter\n\n");
-	fprintf(stderr,"  -nb, --no-bom  do not write Byte Order Mark in UTF8 output\n");
-	fprintf(stderr,"  -s, --single-refperfile one reference per output file\n");
-	fprintf(stderr,"  -h, --help     display this help\n");
-	fprintf(stderr,"  --verbose      for verbose output\n");
-	fprintf(stderr,"  --debug        for debug output\n");
-	fprintf(stderr,"  -v, --version  display version\n\n");
+	fprintf(stderr,"  -h, --help               display this help\n");
+	fprintf(stderr,"  -v, --version            display version\n");
+	fprintf(stderr,"  -nb, --no-bom            do not write Byte Order Mark in UTF8 output\n");
+	fprintf(stderr,"  -s, --single-refperfile  one reference per output file\n");
+	fprintf(stderr,"  --verbose                for verbose output\n");
+	fprintf(stderr,"  --debug                  for debug output\n");
 
-	fprintf(stderr,"http://www.scripps.edu/~cdputnam/software/bibutils for more details\n\n");
+	fprintf(stderr,"\nhttp://sourceforge.net/p/bibutils/home/Bibutils for more details\n\n");
 }
 
 void
@@ -77,7 +76,7 @@ main( int argc, char *argv[] )
 	param p;
 	modsin_initparams( &p, progname );
 	adsout_initparams( &p, progname );
-	process_charsets( &argc, argv, &p, 1, 1 );
+	process_charsets( &argc, argv, &p );
 	process_args( &argc, argv, &p );
 	bibprog( argc, argv, &p );
 	bibl_freeparams( &p );
