@@ -1,14 +1,16 @@
 /*
  * bibl.h
  *
- * Copyright (c) Chris Putnam 2005-9
+ * Copyright (c) Chris Putnam 2005-2017
+ *
+ * Source code released under the GPL version 2
  *
  */
 #ifndef BIBL_H
 #define BIBL_H
 
 #include <stdio.h>
-#include "newstr.h"
+#include "str.h"
 #include "fields.h"
 #include "reftypes.h"
 
@@ -19,9 +21,9 @@ typedef struct {
 } bibl;
 
 extern void bibl_init( bibl *b );
-extern void bibl_addref( bibl *b, fields *ref );
+extern int  bibl_addref( bibl *b, fields *ref );
 extern void bibl_free( bibl *b );
-extern void bibl_copy( bibl *bout, bibl *bin );
+extern int  bibl_copy( bibl *bout, bibl *bin );
 
 #endif
 
