@@ -1,12 +1,11 @@
 /*
  * endtypes.c
  *
- * Copyright (c) Chris Putnam 2003-2010
+ * Copyright (c) Chris Putnam 2003-2017
  *
- * Program and source code released under the GPL
+ * Program and source code released under the GPL version 2
  *
  */
-
 #include <stdio.h>
 #include <string.h>
 #include "is_ws.h"
@@ -19,7 +18,7 @@ static lookups generic[] = {
 	{ "%A", "AUTHOR",    PERSON, LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE,  LEVEL_MAIN },
 	{ "%J", "TITLE",     TITLE,  LEVEL_HOST }, /* for refer formats */
 	{ "%E", "2ND_AUTHOR",PERSON, LEVEL_MAIN },
@@ -31,10 +30,10 @@ static lookups generic[] = {
 	{ "%N", "NUMBER",    SIMPLE, LEVEL_MAIN },
 	{ "%P", "PAGES",        PAGES,  LEVEL_MAIN },
 	{ "%&", "SECTION",      SIMPLE, LEVEL_MAIN },
-	{ "%Y", "3RD_AUTHOR",   PERSON, LEVEL_MAIN },
-	{ "%S", "3RD_TITLE",    SIMPLE, LEVEL_MAIN },
+	{ "%Y", "AUTHOR",   PERSON, LEVEL_SERIES },
+	{ "%S", "TITLE",     TITLE, LEVEL_SERIES },
 	{ "%7", "EDITION",      SIMPLE, LEVEL_MAIN },
-	{ "%8", "MONTH",    DATE,   LEVEL_MAIN },
+	{ "%8", "DATE:MONTH",    DATE,   LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE, LEVEL_MAIN },
 	{ "%?", "SUB_AUTHOR",   PERSON, LEVEL_MAIN }, /* subsidiary-authors */
 	{ "%!", "SHORTTITLE",   TITLE,  LEVEL_MAIN },
@@ -54,7 +53,7 @@ static lookups generic[] = {
 	{ "%K", "KEYWORD",      SIMPLE, LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",     SIMPLE, LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES, LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE, LEVEL_MAIN },
+	{ "%U", "URL",          URL,    LEVEL_MAIN },
 	{ "%>", "PDFLINK",      SIMPLE, LEVEL_MAIN },
 	{ "%Z", "NOTES",        SIMPLE, LEVEL_MAIN },
 	{ "%W", "PHYSICALLOC",  SIMPLE, LEVEL_MAIN },  /* physical location */
@@ -71,7 +70,7 @@ static lookups journalarticle[] = {
 	{ "%A", "AUTHOR",       PERSON,   LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",   PERSON,   LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE",SIMPLE, LEVEL_MAIN },
-	{ "%D", "PARTYEAR",     SIMPLE,   LEVEL_MAIN },
+	{ "%D", "PARTDATE:YEAR",     SIMPLE,   LEVEL_MAIN },
 	{ "%T", "TITLE" ,       TITLE,    LEVEL_MAIN },
 	{ "%J", "TITLE",        TITLE,    LEVEL_HOST }, /* journal title */
 	{ "%B", "TITLE",        TITLE,    LEVEL_HOST }, /* journal title */
@@ -80,7 +79,7 @@ static lookups journalarticle[] = {
 	{ "%N", "ISSUE",        SIMPLE,   LEVEL_MAIN },
 	{ "%P", "PAGES",        PAGES,    LEVEL_MAIN },
 	{ "%I", "PUBLISHER",    SIMPLE,   LEVEL_HOST }, 
-	{ "%8", "PARTMONTH",    DATE,     LEVEL_MAIN },
+	{ "%8", "PARTDATE:MONTH",    DATE,     LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE,   LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",   TITLE,    LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER", SERIALNO, LEVEL_HOST },
@@ -92,7 +91,7 @@ static lookups journalarticle[] = {
 	{ "%F", "REFNUM",       SIMPLE,   LEVEL_MAIN },
 	{ "%K", "KEYWORD",      SIMPLE,   LEVEL_MAIN },
 	{ "%X", "ABSTRACT",     SIMPLE,   LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE,   LEVEL_MAIN },
+	{ "%U", "URL",          URL,      LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES,    LEVEL_MAIN },
 	{ "%Z", "NOTES",        NOTES,    LEVEL_MAIN },
 	{ "%1", "CUSTOM1",      NOTES,    LEVEL_MAIN },
@@ -111,6 +110,7 @@ static lookups journalarticle[] = {
 	{ "%~", "DATABASE",     SIMPLE,   LEVEL_MAIN },
 	{ "  ", "ISSUANCE|continuing",    ALWAYS, LEVEL_HOST },
 	{ "  ", "RESOURCE|text",          ALWAYS, LEVEL_MAIN },
+        { "  ", "GENRE|journal article",  ALWAYS, LEVEL_MAIN },
 	{ "  ", "GENRE|periodical",       ALWAYS, LEVEL_HOST },
 	{ "  ", "GENRE|academic journal", ALWAYS, LEVEL_HOST }
 };
@@ -120,7 +120,7 @@ static lookups magazinearticle[] = {
 	{ "%A", "AUTHOR",    PERSON,  LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "PARTYEAR",  SIMPLE,  LEVEL_MAIN },
+	{ "%D", "PARTDATE:YEAR",  SIMPLE,  LEVEL_MAIN },
 	{ "%T", "TITLE",     TITLE,   LEVEL_MAIN },
 	{ "%J", "TITLE",     TITLE,   LEVEL_HOST }, /* magazine name */
 	{ "%B", "TITLE",     TITLE,   LEVEL_HOST }, /* magazine name */
@@ -129,7 +129,7 @@ static lookups magazinearticle[] = {
 	{ "%N", "ISSUE",     SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE,    LEVEL_HOST }, 
-	{ "%8", "PARTMONTH", DATE,    LEVEL_MAIN },
+	{ "%8", "PARTDATE:MONTH", DATE,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER",      SERIALNO,LEVEL_HOST },
 	{ "%(", "TITLE",     SIMPLE,  LEVEL_ORIG }, /* original pub */
@@ -140,7 +140,7 @@ static lookups magazinearticle[] = {
 	{ "%F", "REFNUM",    SIMPLE,  LEVEL_MAIN },
 	{ "%K", "KEYWORD",   SIMPLE,  LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,  LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,  LEVEL_MAIN },
+	{ "%U", "URL",       URL,     LEVEL_MAIN },
 	{ "%O", "NOTES",     SIMPLE,  LEVEL_MAIN },
 	{ "%Z", "NOTES",     SIMPLE,  LEVEL_MAIN },
 	{ "%1", "CUSTOM1",      NOTES,    LEVEL_MAIN },
@@ -168,7 +168,7 @@ static lookups newspaperarticle[] = {
 	{ "%A", "REPORTER",  PERSON,  LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "PARTYEAR",  SIMPLE,  LEVEL_MAIN },
+	{ "%D", "PARTDATE:YEAR",  SIMPLE,  LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE,   LEVEL_MAIN },
 	{ "%J", "TITLE",     TITLE,   LEVEL_HOST }, /* newspaper name */
 	{ "%B", "TITLE",     TITLE,   LEVEL_HOST }, /* newspaper name */
@@ -177,7 +177,7 @@ static lookups newspaperarticle[] = {
 	{ "%N", "ISSUE",     SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
 	{ "%7", "EDITION",   SIMPLE,  LEVEL_MAIN },
-	{ "%8", "PARTMONTH", DATE,    LEVEL_MAIN },
+	{ "%8", "PARTDATE:MONTH", DATE,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER",      SERIALNO, LEVEL_MAIN },
 	{ "%(", "TITLE",     SIMPLE, LEVEL_ORIG }, /* original pub */
@@ -188,7 +188,7 @@ static lookups newspaperarticle[] = {
 	{ "%F", "REFNUM",    SIMPLE,  LEVEL_MAIN },
 	{ "%K", "KEYWORD",   SIMPLE,  LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,  LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,  LEVEL_MAIN },
+	{ "%U", "URL",       URL,     LEVEL_MAIN },
 	{ "%O", "NOTES",     SIMPLE,  LEVEL_MAIN },
 	{ "%Z", "NOTES",     SIMPLE,  LEVEL_MAIN },
 	{ "%1", "CUSTOM1",      NOTES,    LEVEL_MAIN },
@@ -215,7 +215,7 @@ static lookups book[] = {
 	{ "%A", "AUTHOR",    PERSON,    LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE,    LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE,    LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE,     LEVEL_MAIN },
 	{ "%E", "AUTHOR",    PERSON,    LEVEL_HOST }, /* SERIES_AUTHOR */
 	{ "%B", "TITLE",     TITLE,     LEVEL_HOST }, /* SERIES_TITLE */
@@ -225,7 +225,7 @@ static lookups book[] = {
 	{ "%V", "VOLUME" ,   SIMPLE,    LEVEL_MAIN },
 	{ "%N", "NUMBER",    SIMPLE,    LEVEL_MAIN },
 	{ "%6", "NUMVOLUMES",SIMPLE,    LEVEL_MAIN },
-	{ "%P", "TOTALPAGES", SIMPLE,LEVEL_MAIN },
+	{ "%P", "PAGES:TOTAL", SIMPLE,LEVEL_MAIN },
 	{ "%7", "EDITION",   SIMPLE,    LEVEL_MAIN },
 	{ "%?", "TRANSLATOR",PERSON,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,     LEVEL_MAIN },
@@ -244,7 +244,7 @@ static lookups book[] = {
 	{ "%K", "KEYWORD",   SIMPLE,    LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,    LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,     LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,    LEVEL_MAIN },
+	{ "%U", "URL",       URL,       LEVEL_MAIN },
 	{ "%Z", "NOTES",     SIMPLE,    LEVEL_MAIN },
 	{ "%+", "AUTHORADDRESS",SIMPLE, LEVEL_MAIN },
 	{ "%>", "PDFLINK",      SIMPLE, LEVEL_MAIN },
@@ -264,7 +264,7 @@ static lookups booksection[] = {
 	{ "%A", "AUTHOR",    PERSON,    LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE,    LEVEL_HOST },
+	{ "%D", "DATE:YEAR",      SIMPLE,    LEVEL_HOST },
 	{ "%T", "TITLE" ,    TITLE,     LEVEL_MAIN },
 	{ "%E", "EDITOR",    PERSON,    LEVEL_HOST }, /* editor for book */
 	{ "%B", "TITLE",     TITLE,     LEVEL_HOST }, /* book title */
@@ -294,7 +294,7 @@ static lookups booksection[] = {
 	{ "%K", "KEYWORD",   SIMPLE,    LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,    LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,     LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,    LEVEL_MAIN },
+	{ "%U", "URL",       URL,       LEVEL_MAIN },
 	{ "%Z", "NOTES",     SIMPLE,    LEVEL_MAIN },
 	{ "%+", "AUTHORADDRESS",SIMPLE, LEVEL_MAIN },
 	{ "%>", "PDFLINK",      SIMPLE, LEVEL_MAIN },
@@ -304,9 +304,10 @@ static lookups booksection[] = {
 	{ "%[", "ACCESSDATE",   SIMPLE, LEVEL_MAIN },
 	{ "%=", "LASTMODDATE",  SIMPLE, LEVEL_MAIN },
 	{ "%~", "DATABASE",     SIMPLE, LEVEL_MAIN },
-	{ "  ", "GENRE|book", ALWAYS, LEVEL_HOST },
+        { "  ", "GENRE|book chapter",   ALWAYS, LEVEL_MAIN },
+	{ "  ", "GENRE|book",           ALWAYS, LEVEL_HOST },
 	{ "  ", "ISSUANCE|monographic", ALWAYS, LEVEL_HOST },
-	{ "  ", "RESOURCE|text", ALWAYS, LEVEL_MAIN }
+	{ "  ", "RESOURCE|text",        ALWAYS, LEVEL_MAIN }
 };
 
 static lookups editedbook[] = {
@@ -314,7 +315,7 @@ static lookups editedbook[] = {
 	{ "%A", "EDITOR",    PERSON,    LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE,    LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE,    LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE,     LEVEL_MAIN },
 	{ "%E", "EDITOR",    PERSON,    LEVEL_HOST }, /* SERIES_EDITOR */
 	{ "%B", "TITLE",     TITLE,     LEVEL_HOST }, /* SERIES_TITLE */
@@ -323,7 +324,7 @@ static lookups editedbook[] = {
 	{ "%N", "NUMBER",    SIMPLE,    LEVEL_MAIN },
 	{ "%V", "VOLUME" ,   SIMPLE,    LEVEL_MAIN },
 	{ "%6", "NUMVOLUMES",SIMPLE,    LEVEL_HOST },
-	{ "%P", "TOTALPAGES", SIMPLE,LEVEL_MAIN },
+	{ "%P", "PAGES:TOTAL", SIMPLE,LEVEL_MAIN },
 	{ "%7", "EDITION",   SIMPLE,    LEVEL_MAIN },
 	{ "%?", "TRANSLATOR",PERSON,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,     LEVEL_MAIN },
@@ -342,7 +343,7 @@ static lookups editedbook[] = {
 	{ "%K", "KEYWORD",   SIMPLE,    LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,    LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,     LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,    LEVEL_MAIN },
+	{ "%U", "URL",       URL,       LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,     LEVEL_MAIN },
 	{ "%+", "AUTHORADDRESS",SIMPLE, LEVEL_MAIN },
 	{ "%>", "PDFLINK",      SIMPLE, LEVEL_MAIN },
@@ -362,13 +363,13 @@ static lookups manuscript[] = {
 	{ "%A", "AUTHOR",    PERSON,  LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE,  LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE,  LEVEL_MAIN },
 	{ "%T", "TITLE",     TITLE,   LEVEL_MAIN },
 	{ "%B", "TITLE",     TITLE,   LEVEL_HOST }, /* COLLECTION_TITLE */
 	{ "%C", "ADDRESS",   SIMPLE,  LEVEL_MAIN },
 	{ "%N", "NUMBER",    SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
-	{ "%8", "MONTH", DATE,    LEVEL_MAIN },
+	{ "%8", "DATE:MONTH", DATE,    LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE,  LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%M", "ACCESSNUM", SIMPLE,  LEVEL_MAIN },
@@ -377,7 +378,7 @@ static lookups manuscript[] = {
 	{ "%K", "KEYWORD",   SIMPLE,  LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,  LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,   LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,  LEVEL_MAIN },
+	{ "%U", "URL",       URL,     LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,   LEVEL_MAIN },
 	{ "%1", "CUSTOM1",   NOTES,   LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   NOTES,   LEVEL_MAIN },
@@ -402,13 +403,13 @@ static lookups communication[] = {
 	{ "%A", "AUTHOR",    PERSON,  LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE,  LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE,  LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE,   LEVEL_MAIN },
 	{ "%E", "RECIPIENT", PERSON,  LEVEL_MAIN },
 	{ "%C", "ADDRESS",   SIMPLE,  LEVEL_MAIN },
 	{ "%V", "VOLUME",    SIMPLE,  LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE,  LEVEL_MAIN },
-	{ "%8", "MONTH", DATE,    LEVEL_MAIN },
+	{ "%8", "DATE:MONTH", DATE,    LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE,  LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%M", "ACCESSNUM", SIMPLE,  LEVEL_MAIN },
@@ -417,7 +418,7 @@ static lookups communication[] = {
 	{ "%K", "KEYWORD",   SIMPLE,  LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,  LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,   LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,  LEVEL_MAIN },
+	{ "%U", "URL",       URL,     LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,   LEVEL_MAIN },
 	{ "%1", "CUSTOM1",   NOTES,   LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   NOTES,   LEVEL_MAIN },
@@ -441,7 +442,7 @@ static lookups proceedings[] = {
 	{ "%A", "AUTHOR",    PERSON,  LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE,  LEVEL_HOST },
+	{ "%D", "DATE:YEAR",      SIMPLE,  LEVEL_HOST },
 	{ "%T", "TITLE" ,    TITLE,   LEVEL_MAIN },
 	{ "%E", "EDITOR",    PERSON,  LEVEL_MAIN },
 	{ "%B", "TITLE",     SIMPLE,  LEVEL_HOST }, 
@@ -451,10 +452,10 @@ static lookups proceedings[] = {
 	{ "%6", "NUMVOLUMES",SIMPLE,  LEVEL_HOST },
 	{ "%N", "NUMBER",    SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
-	{ "%Y", "EDITOR",    PERSON,  LEVEL_HOST }, /* SERIES_EDITOR */
-	{ "%S", "TITLE",     TITLE,   LEVEL_HOST+1 }, /* SERIES_TITLE */
+	{ "%Y", "EDITOR",    PERSON,  LEVEL_SERIES },
+	{ "%S", "TITLE",     TITLE,   LEVEL_SERIES },
 	{ "%7", "EDITION",   SIMPLE,  LEVEL_HOST },
-	{ "%8", "MONTH", DATE,    LEVEL_MAIN },
+	{ "%8", "DATE:MONTH", DATE,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%1", "CUSTOM1",   NOTES,   LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   NOTES,   LEVEL_MAIN },
@@ -468,7 +469,7 @@ static lookups proceedings[] = {
 	{ "%K", "KEYWORD",   SIMPLE,  LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,  LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,   LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,  LEVEL_MAIN },
+	{ "%U", "URL",       URL,     LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,   LEVEL_MAIN },
 	{ "%+", "AUTHORADDRESS",SIMPLE,LEVEL_MAIN},
 	{ "%>", "PDFLINK",      SIMPLE, LEVEL_MAIN },
@@ -487,7 +488,7 @@ static lookups conferencepaper[] = {
 	{ "%A", "AUTHOR",       PERSON,   LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",   PERSON,   LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE",SIMPLE, LEVEL_MAIN },
-	{ "%D", "PARTYEAR",     SIMPLE,   LEVEL_MAIN },
+	{ "%D", "PARTDATE:YEAR",     SIMPLE,   LEVEL_MAIN },
 	{ "%T", "TITLE" ,       TITLE,    LEVEL_MAIN },
 	{ "%J", "TITLE",        TITLE,    LEVEL_HOST }, /* journal title */
 	{ "%B", "TITLE",        TITLE,    LEVEL_HOST }, /* journal title */
@@ -496,7 +497,7 @@ static lookups conferencepaper[] = {
 	{ "%N", "ISSUE",        SIMPLE,   LEVEL_MAIN },
 	{ "%P", "PAGES",        PAGES,    LEVEL_MAIN },
 	{ "%I", "PUBLISHER",    SIMPLE,   LEVEL_HOST }, 
-	{ "%8", "PARTMONTH",    DATE,     LEVEL_MAIN },
+	{ "%8", "PARTDATE:MONTH",    DATE,     LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE,   LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",   TITLE,    LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER", SERIALNO, LEVEL_HOST },
@@ -508,7 +509,7 @@ static lookups conferencepaper[] = {
 	{ "%F", "REFNUM",       SIMPLE,   LEVEL_MAIN },
 	{ "%K", "KEYWORD",      SIMPLE,   LEVEL_MAIN },
 	{ "%X", "ABSTRACT",     SIMPLE,   LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE,   LEVEL_MAIN },
+	{ "%U", "URL",          URL,      LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES,    LEVEL_MAIN },
 	{ "%Z", "NOTES",        NOTES,    LEVEL_MAIN },
 	{ "%1", "CUSTOM1",      NOTES,    LEVEL_MAIN },
@@ -534,15 +535,15 @@ static lookups thesis[] = {
 	{ "%A", "AUTHOR",       PERSON, LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",   PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",         SIMPLE, LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",         SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,       TITLE,  LEVEL_MAIN },
 	{ "%B", "ACADEMIC_DEPARTMENT", SIMPLE, LEVEL_MAIN },
 	{ "%C", "ADDRESS",      SIMPLE, LEVEL_MAIN },
 	{ "%I", "PUBLISHER",    SIMPLE, LEVEL_MAIN }, 
 	{ "%V", "VOLUME",       SIMPLE, LEVEL_MAIN },
-	{ "%P", "NUMPAGES",     PAGES,  LEVEL_MAIN },
+	{ "%P", "PAGES:TOTAL",  PAGES,  LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE, LEVEL_MAIN }, /* thesis type */
-	{ "%8", "MONTH",        DATE,   LEVEL_MAIN },
+	{ "%8", "DATE:MONTH",   DATE,   LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",   TITLE,  LEVEL_MAIN },
 	{ "%1", "CUSTOM1",      NOTES,  LEVEL_MAIN },
 	{ "%2", "CUSTOM2",      NOTES,  LEVEL_MAIN },
@@ -556,7 +557,7 @@ static lookups thesis[] = {
 	{ "%K", "KEYWORD",      SIMPLE, LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",     SIMPLE, LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES,  LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE, LEVEL_MAIN },
+	{ "%U", "URL",          URL,    LEVEL_MAIN },
 	{ "%Z", "NOTES",        NOTES,  LEVEL_MAIN },
 	{ "%+", "AUTHORADDRESS",SIMPLE, LEVEL_MAIN },
 	{ "%>", "PDFLINK",      SIMPLE, LEVEL_MAIN },
@@ -575,7 +576,7 @@ static lookups program[] = {
 	{ "%A", "AUTHOR",    PERSON   , LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE   , LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE   , LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE    , LEVEL_MAIN },
 	{ "%C", "ADDRESS",   SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE   , LEVEL_MAIN },
@@ -587,7 +588,7 @@ static lookups program[] = {
 	{ "%K", "KEYWORD",   SIMPLE   , LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE   , LEVEL_MAIN },
 	{ "%O", "NOTES",     SIMPLE   , LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE   , LEVEL_MAIN },
+	{ "%U", "URL",       URL,       LEVEL_MAIN },
 	{ "%Z", "NOTES",     SIMPLE   , LEVEL_MAIN },
 	{ "%1", "COMPUTER",  SIMPLE   , LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   SIMPLE   , LEVEL_MAIN },
@@ -612,14 +613,14 @@ static lookups audiovisual[] = {
 	{ "%A", "WRITER",    PERSON   , LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE   , LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE   , LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE    , LEVEL_MAIN },
 	{ "%B", "TITLE",     TITLE    , LEVEL_HOST }, /* COLLECTION_TITLE */
 	{ "%C", "ADDRESS",   SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE   , LEVEL_MAIN },
 	{ "%V", "EXTENTOFWORK",     SIMPLE   , LEVEL_MAIN },
 	{ "%N", "NUMBER",    SIMPLE   , LEVEL_MAIN },
-	{ "%8", "MONTH", DATE     , LEVEL_MAIN },
+	{ "%8", "DATE:MONTH", DATE     , LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE   , LEVEL_MAIN },
 	{ "%?", "PERFORMER", PERSON   , LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE    , LEVEL_MAIN },
@@ -629,7 +630,7 @@ static lookups audiovisual[] = {
 	{ "%K", "KEYWORD",   SIMPLE   , LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE   , LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,     LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE   , LEVEL_MAIN },
+	{ "%U", "URL",       URL,       LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,     LEVEL_MAIN },
 	{ "%1", "CUSTOM1",   NOTES,     LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   NOTES,     LEVEL_MAIN },
@@ -653,14 +654,14 @@ static lookups broadcast[] = {
 	{ "%A", "AUTHOR",       PERSON,   LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",   PERSON,   LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",         SIMPLE,   LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",         SIMPLE,   LEVEL_MAIN },
 	{ "%T", "TITLE" ,       TITLE,    LEVEL_MAIN },
 	{ "%E", "DIRECTOR",     PERSON,   LEVEL_MAIN },
 	{ "%B", "TITLE",        TITLE,    LEVEL_HOST }, /* SERIES_TITLE */
 	{ "%C", "ADDRESS",      SIMPLE,   LEVEL_MAIN },
 	{ "%I", "PUBLISHER",    SIMPLE,   LEVEL_MAIN },
 	{ "%Y", "PRODUCER",     PERSON,   LEVEL_MAIN },
-	{ "%8", "MONTH",        DATE,     LEVEL_MAIN },
+	{ "%8", "DATE:MONTH",        DATE,     LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE,   LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",   TITLE,    LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER", SERIALNO, LEVEL_MAIN },
@@ -671,7 +672,7 @@ static lookups broadcast[] = {
 	{ "%K", "KEYWORD",      SIMPLE,   LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",     SIMPLE,   LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES,    LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE,   LEVEL_MAIN },
+	{ "%U", "URL",          URL,      LEVEL_MAIN },
 	{ "%Z", "NOTES",        SIMPLE,   LEVEL_MAIN },
 	{ "%1", "CUSTOM1",      NOTES,    LEVEL_MAIN },
 	{ "%2", "CUSTOM2",      NOTES,    LEVEL_MAIN },
@@ -695,7 +696,7 @@ static lookups electronic[] = {
 	{ "%A", "AUTHOR",    PERSON    , LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE    , LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE    , LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE     , LEVEL_MAIN },
 	{ "%C", "ADDRESS",   SIMPLE, LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE    , LEVEL_MAIN }, 
@@ -716,7 +717,7 @@ static lookups electronic[] = {
 	{ "%K", "KEYWORD",   SIMPLE,     LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,     LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,      LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,     LEVEL_MAIN },
+	{ "%U", "URL",       URL,        LEVEL_MAIN },
 	{ "%V", "VOLUME",    SIMPLE,     LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,      LEVEL_MAIN },
 	{ "%W", "PHYSICALLOC",  SIMPLE, LEVEL_MAIN },  /* physical location */
@@ -736,7 +737,7 @@ static lookups webpage[] = {
 	{ "%A", "AUTHOR",    PERSON    , LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE    , LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE    , LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE     , LEVEL_MAIN },
 	{ "%C", "ADDRESS",   SIMPLE, LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE    , LEVEL_MAIN }, 
@@ -757,7 +758,7 @@ static lookups webpage[] = {
 	{ "%K", "KEYWORD",   SIMPLE,     LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,     LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,      LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,     LEVEL_MAIN },
+	{ "%U", "URL",       URL,        LEVEL_MAIN },
 	{ "%V", "VOLUME",    SIMPLE,     LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,      LEVEL_MAIN },
 	{ "%W", "PHYSICALLOC",  SIMPLE, LEVEL_MAIN },  /* physical location */
@@ -777,11 +778,11 @@ static lookups artwork[] = {
 	{ "%A", "ARTIST",    PERSON   , LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",         SIMPLE   , LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",         SIMPLE   , LEVEL_MAIN },
 	{ "%T", "TITLE" ,       TITLE    , LEVEL_MAIN },
 	{ "%C", "ADDRESS",      SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER",    SIMPLE   , LEVEL_MAIN },
-	{ "%8", "MONTH",        DATE,   LEVEL_MAIN },
+	{ "%8", "DATE:MONTH",        DATE,   LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE, LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",   TITLE,  LEVEL_MAIN },
 	{ "%M", "ACCESSNUM",    SIMPLE, LEVEL_MAIN },
@@ -790,7 +791,7 @@ static lookups artwork[] = {
 	{ "%K", "KEYWORD",      SIMPLE, LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",     SIMPLE, LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES,  LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE, LEVEL_MAIN },
+	{ "%U", "URL",          URL,    LEVEL_MAIN },
 	{ "%Z", "NOTES",        NOTES,  LEVEL_MAIN },
 	{ "%1", "CUSTOM1",      NOTES,  LEVEL_MAIN },
 	{ "%2", "CUSTOM2",      NOTES,  LEVEL_MAIN },
@@ -814,12 +815,12 @@ static lookups report[] = {
 	{ "%A", "AUTHOR",    PERSON   , LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE   , LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE   , LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE    , LEVEL_MAIN },
 	{ "%C", "ADDRESS",   SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE, LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES, LEVEL_MAIN },
-	{ "%8", "MONTH",     DATE, LEVEL_MAIN },
+	{ "%8", "DATE:MONTH",     DATE, LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE,    LEVEL_MAIN },
 	{ "%N", "NUMBER",    SIMPLE,    LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER", SERIALNO, LEVEL_MAIN },
@@ -830,7 +831,7 @@ static lookups report[] = {
 	{ "%K", "KEYWORD",   SIMPLE,    LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE,    LEVEL_MAIN },
 	{ "%O", "NOTES",     NOTES,     LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE,    LEVEL_MAIN },
+	{ "%U", "URL",       URL,       LEVEL_MAIN },
 	{ "%Z", "NOTES",     NOTES,     LEVEL_MAIN },
 	{ "%1", "CUSTOM1",   NOTES,     LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   NOTES,     LEVEL_MAIN },
@@ -855,7 +856,7 @@ static lookups map[] = {
 	{ "%A", "CARTOGRAPHER",    PERSON   , LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE   , LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE   , LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE    , LEVEL_MAIN },
 	{ "%C", "ADDRESS",   SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE   , LEVEL_MAIN },
@@ -868,7 +869,7 @@ static lookups map[] = {
 	{ "%K", "KEYWORD",   SIMPLE   , LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",  SIMPLE   , LEVEL_MAIN },
 	{ "%O", "NOTES",     SIMPLE   , LEVEL_MAIN },
-	{ "%U", "URL",       SIMPLE   , LEVEL_MAIN },
+	{ "%U", "URL",       URL,       LEVEL_MAIN },
 	{ "%Z", "NOTES",     SIMPLE   , LEVEL_MAIN },
 	{ "%1", "SCALE",     SIMPLE   , LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   SIMPLE   , LEVEL_MAIN },
@@ -893,7 +894,7 @@ static lookups patent[] = {
 	{ "%A", "AUTHOR",    PERSON, LEVEL_MAIN  },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN  },
+	{ "%D", "DATE:YEAR",      SIMPLE, LEVEL_MAIN  },
 	{ "%T", "TITLE" ,    TITLE, LEVEL_MAIN   },
 	{ "%B", "PUBLISHED_SOURCE", SIMPLE, LEVEL_MAIN},
 	{ "%C", "COUNTRY",   SIMPLE, LEVEL_MAIN  },
@@ -908,7 +909,7 @@ static lookups patent[] = {
 	{ "%K", "KEYWORD",   SIMPLE, LEVEL_MAIN  }, 
 	{ "%X", "ABSTRACT",  SIMPLE, LEVEL_MAIN  },
 	{ "%O", "NOTES",     SIMPLE, LEVEL_MAIN  },
-	{ "%U", "URL",       SIMPLE, LEVEL_MAIN  },
+	{ "%U", "URL",       URL,    LEVEL_MAIN  },
 	{ "%Z", "NOTES",     SIMPLE, LEVEL_MAIN  },
 	{ "%1", "SCALE",     SIMPLE, LEVEL_MAIN  },
 	{ "%2", "CUSTOM2",   SIMPLE, LEVEL_MAIN  },
@@ -930,7 +931,7 @@ static lookups patent[] = {
 
 static lookups hearing[] = {
 	{ "%0", "INTERNAL_TYPE",         TYPE, LEVEL_MAIN    },
-	{ "%D", "YEAR",         SIMPLE, LEVEL_MAIN  },
+	{ "%D", "DATE:YEAR",         SIMPLE, LEVEL_MAIN  },
 	{ "%H", "TRANSLATOR",   PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,       TITLE, LEVEL_MAIN   },
@@ -939,10 +940,10 @@ static lookups hearing[] = {
 	{ "%I", "PUBLISHER",    SIMPLE, LEVEL_MAIN  }, 
 	{ "%6", "NUMVOLUMES",   SIMPLE, LEVEL_MAIN  },
 	{ "%N", "NUMBER",       SIMPLE, LEVEL_MAIN  },
-	{ "%P", "NUMPAGES",     PAGES,  LEVEL_MAIN  },
+	{ "%P", "PAGES:TOTAL",  PAGES,  LEVEL_MAIN  },
 	{ "%S", "LEGISLATIVEBODY:CORP", SIMPLE, LEVEL_MAIN  },
 	{ "%7", "SESSION",       SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTH",         DATE,   LEVEL_MAIN  },
+	{ "%8", "DATE:MONTH",         DATE,   LEVEL_MAIN  },
 	{ "%!", "SHORTTITLE",    TITLE,  LEVEL_MAIN  },
 	{ "%(", "TITLE",         SIMPLE, LEVEL_ORIG }, /* orig publication */
 	{ "%M", "ACCESSNUM",     SIMPLE, LEVEL_MAIN  },
@@ -951,7 +952,7 @@ static lookups hearing[] = {
 	{ "%K", "KEYWORD",       SIMPLE, LEVEL_MAIN  }, 
 	{ "%X", "ABSTRACT",      SIMPLE, LEVEL_MAIN  },
 	{ "%O", "NOTES",         NOTES,  LEVEL_MAIN  },
-	{ "%U", "URL",           SIMPLE, LEVEL_MAIN  },
+	{ "%U", "URL",           URL,    LEVEL_MAIN  },
 	{ "%Z", "NOTES",         NOTES,  LEVEL_MAIN  },
 	{ "%1", "CUSTOM1",       NOTES,  LEVEL_MAIN  },
 	{ "%2", "CUSTOM2",       NOTES,  LEVEL_MAIN  },
@@ -972,7 +973,7 @@ static lookups hearing[] = {
 
 static lookups bill[] = {
 	{ "%0", "INTERNAL_TYPE",      TYPE, LEVEL_MAIN    },
-	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN  },
+	{ "%D", "DATE:YEAR",      SIMPLE, LEVEL_MAIN  },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE, LEVEL_MAIN   },
@@ -983,7 +984,7 @@ static lookups bill[] = {
 	{ "%&", "CODESECTION",SIMPLE, LEVEL_MAIN  },
 	{ "%S", "LEGISLATIVEBODY:CORP", SIMPLE, LEVEL_MAIN  },
 	{ "%7", "SESSION",   SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTH", DATE, LEVEL_MAIN    },
+	{ "%8", "DATE:MONTH", DATE, LEVEL_MAIN    },
 	{ "%?", "SPONSOR",   PERSON, LEVEL_MAIN  },
 	{ "%!", "SHORTTITLE",TITLE,  LEVEL_MAIN   },
 	{ "%(", "TITLE",     SIMPLE, LEVEL_ORIG  }, /* original pub */
@@ -993,7 +994,7 @@ static lookups bill[] = {
 	{ "%K", "KEYWORD",   SIMPLE, LEVEL_MAIN  }, 
 	{ "%X", "ABSTRACT",  SIMPLE, LEVEL_MAIN  },
 	{ "%O", "NOTES",     NOTES,  LEVEL_MAIN  },
-	{ "%U", "URL",       SIMPLE, LEVEL_MAIN  },
+	{ "%U", "URL",       URL,    LEVEL_MAIN  },
 	{ "%Z", "NOTES",     NOTES,  LEVEL_MAIN  },
 	{ "%1", "CUSTOM1",   NOTES,  LEVEL_MAIN  },
 	{ "%2", "CUSTOM2",   NOTES,  LEVEL_MAIN  },
@@ -1014,7 +1015,7 @@ static lookups bill[] = {
 
 static lookups statute[] = {
 	{ "%0", "INTERNAL_TYPE",      TYPE, LEVEL_MAIN    },
-	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN  },
+	{ "%D", "DATE:YEAR",      SIMPLE, LEVEL_MAIN  },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE, LEVEL_MAIN   },
@@ -1024,7 +1025,7 @@ static lookups statute[] = {
 	{ "%P", "PAGES",     PAGES, LEVEL_MAIN    },
 	{ "%&", "SECTION",   SIMPLE, LEVEL_MAIN  },
 	{ "%7", "SESSION",   SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTH", DATE, LEVEL_MAIN    },
+	{ "%8", "DATE:MONTH", DATE, LEVEL_MAIN    },
 	{ "%!", "SHORTTITLE",TITLE,  LEVEL_MAIN   },
 	{ "%(", "TITLE",     SIMPLE, LEVEL_ORIG  }, /* original pub */
 	{ "%M", "ACCESSNUM", SIMPLE, LEVEL_MAIN  },
@@ -1033,7 +1034,7 @@ static lookups statute[] = {
 	{ "%K", "KEYWORD",   SIMPLE, LEVEL_MAIN  }, 
 	{ "%X", "ABSTRACT",  SIMPLE, LEVEL_MAIN  },
 	{ "%O", "NOTES",     NOTES,  LEVEL_MAIN  },
-	{ "%U", "URL",       SIMPLE, LEVEL_MAIN  },
+	{ "%U", "URL",       URL,    LEVEL_MAIN  },
 	{ "%Z", "NOTES",     NOTES,  LEVEL_MAIN  },
 	{ "%1", "CUSTOM1",   NOTES,  LEVEL_MAIN  },
 	{ "%2", "CUSTOM2",   NOTES,  LEVEL_MAIN  },
@@ -1054,7 +1055,7 @@ static lookups statute[] = {
 
 static lookups lawcase[] = {
 	{ "%0", "INTERNAL_TYPE",      TYPE, LEVEL_MAIN    },
-	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN  },
+	{ "%D", "DATE:YEAR",      SIMPLE, LEVEL_MAIN  },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE, LEVEL_MAIN   },
@@ -1064,7 +1065,7 @@ static lookups lawcase[] = {
 	{ "%V", "VOLUME",    SIMPLE, LEVEL_MAIN   },
 	{ "%N", "PUBLICLAWNUMBER",    SIMPLE, LEVEL_MAIN  },
 	{ "%P", "STARTPAGE",     SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTH", DATE, LEVEL_MAIN    },
+	{ "%8", "DATE:MONTH", DATE, LEVEL_MAIN    },
 	{ "%?", "COUNSEL",   PERSON, LEVEL_MAIN  },
 	{ "%!", "SHORTTITLE",TITLE,  LEVEL_MAIN   },
 	{ "%(", "TITLE",     SIMPLE, LEVEL_ORIG  }, /* original pub */
@@ -1074,7 +1075,7 @@ static lookups lawcase[] = {
 	{ "%K", "KEYWORD",   SIMPLE, LEVEL_MAIN  }, 
 	{ "%X", "ABSTRACT",  SIMPLE, LEVEL_MAIN  },
 	{ "%O", "NOTES",     NOTES,  LEVEL_MAIN  },
-	{ "%U", "URL",       SIMPLE, LEVEL_MAIN  },
+	{ "%U", "URL",       URL,    LEVEL_MAIN  },
 	{ "%Z", "NOTES",     NOTES,  LEVEL_MAIN  },
 	{ "%1", "CUSTOM1",   NOTES,  LEVEL_MAIN  },
 	{ "%2", "CUSTOM2",   NOTES,  LEVEL_MAIN  },
@@ -1098,7 +1099,7 @@ static lookups chart[] = {
 	{ "%A", "AUTHOR",    PERSON, LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE,  LEVEL_MAIN },
 	{ "%J", "TITLE",     TITLE,  LEVEL_HOST }, /* for refer formats */
 	{ "%E", "2ND_AUTHOR",PERSON, LEVEL_MAIN },
@@ -1108,13 +1109,13 @@ static lookups chart[] = {
 	{ "%V", "VOLUME" ,   SIMPLE, LEVEL_MAIN },
 	{ "%6", "NUMVOLUMES",SIMPLE, LEVEL_HOST },
 	{ "%N", "NUMBER",    SIMPLE, LEVEL_MAIN },
-	{ "%P", "PAGES",        PAGES,  LEVEL_MAIN },
-	{ "%&", "SECTION",      SIMPLE, LEVEL_MAIN },
-	{ "%Y", "3RD_AUTHOR",   PERSON, LEVEL_MAIN },
-	{ "%S", "3RD_TITLE",    SIMPLE, LEVEL_MAIN },
-	{ "%7", "EDITION",      SIMPLE, LEVEL_MAIN },
-	{ "%8", "MONTH",    DATE,   LEVEL_MAIN },
-	{ "%9", "GENRE",        SIMPLE, LEVEL_MAIN },
+	{ "%P", "PAGES",     PAGES,  LEVEL_MAIN },
+	{ "%&", "SECTION",   SIMPLE, LEVEL_MAIN },
+	{ "%Y", "AUTHOR",    PERSON, LEVEL_SERIES },
+	{ "%S", "TITLE",     TITLE,  LEVEL_SERIES },
+	{ "%7", "EDITION",   SIMPLE, LEVEL_MAIN },
+	{ "%8", "DATE:MONTH",     DATE,   LEVEL_MAIN },
+	{ "%9", "GENRE",     SIMPLE, LEVEL_MAIN },
 	{ "%?", "SUB_AUTHOR",   PERSON, LEVEL_MAIN }, /* subsidiary-authors */
 	{ "%!", "SHORTTITLE",   TITLE,  LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER", SERIALNO,  LEVEL_MAIN },
@@ -1133,7 +1134,7 @@ static lookups chart[] = {
 	{ "%K", "KEYWORD",      SIMPLE, LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",     SIMPLE, LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES,  LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE, LEVEL_MAIN },
+	{ "%U", "URL",          URL,    LEVEL_MAIN },
 	{ "%Z", "NOTES",        NOTES,  LEVEL_MAIN },
 	{ "%W", "PHYSICALLOC",  SIMPLE, LEVEL_MAIN },  /* physical location */
 	{ "%+", "AUTHORADDRESS",SIMPLE, LEVEL_MAIN },
@@ -1151,7 +1152,7 @@ static lookups unpublished[] = {
 	{ "%A", "AUTHOR",    PERSON, LEVEL_MAIN },
 	{ "%H", "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "%Q", "TRANSLATEDTITLE", SIMPLE, LEVEL_MAIN },
-	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN },
+	{ "%D", "DATE:YEAR",      SIMPLE, LEVEL_MAIN },
 	{ "%T", "TITLE" ,    TITLE,  LEVEL_MAIN },
 	{ "%J", "TITLE",     TITLE,  LEVEL_HOST }, /* for refer formats */
 	{ "%E", "2ND_AUTHOR",PERSON, LEVEL_MAIN },
@@ -1163,10 +1164,10 @@ static lookups unpublished[] = {
 	{ "%N", "NUMBER",    SIMPLE, LEVEL_MAIN },
 	{ "%P", "PAGES",        PAGES,  LEVEL_MAIN },
 	{ "%&", "SECTION",      SIMPLE, LEVEL_MAIN },
-	{ "%Y", "3RD_AUTHOR",   PERSON, LEVEL_MAIN },
-	{ "%S", "3RD_TITLE",    SIMPLE, LEVEL_MAIN },
+	{ "%Y", "AUTHOR",   PERSON, LEVEL_SERIES },
+	{ "%S", "TITLE",    TITLE, LEVEL_SERIES },
 	{ "%7", "EDITION",      SIMPLE, LEVEL_MAIN },
-	{ "%8", "MONTH",    DATE,   LEVEL_MAIN },
+	{ "%8", "DATE:MONTH",    DATE,   LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE, LEVEL_MAIN },
 	{ "%?", "SUB_AUTHOR",   PERSON, LEVEL_MAIN }, /* subsidiary-authors */
 	{ "%!", "SHORTTITLE",   TITLE,  LEVEL_MAIN },
@@ -1186,7 +1187,7 @@ static lookups unpublished[] = {
 	{ "%K", "KEYWORD",      SIMPLE, LEVEL_MAIN }, 
 	{ "%X", "ABSTRACT",     SIMPLE, LEVEL_MAIN },
 	{ "%O", "NOTES",        NOTES,  LEVEL_MAIN },
-	{ "%U", "URL",          SIMPLE, LEVEL_MAIN },
+	{ "%U", "URL",          URL,    LEVEL_MAIN },
 	{ "%>", "PDFLINK",      SIMPLE, LEVEL_MAIN },
 	{ "%Z", "NOTES",        NOTES,  LEVEL_MAIN },
 	{ "%W", "PHYSICALLOC",  SIMPLE, LEVEL_MAIN },  /* physical location */
