@@ -1,27 +1,40 @@
 /*
  * endxmlin.c
  *
- * Copyright (c) Chris Putnam 2006-2010
+ * Copyright (c) Chris Putnam 2006-2017
+ *
+ * Program and source code released under the GPL version 2
  *
- * Program and source code released under the GPL
  */
 #include <stdio.h>
 #include <stdlib.h>
-#include "newstr.h"
-#include "newstr_conv.h"
+#include "str.h"
+#include "str_conv.h"
 #include "fields.h"
 #include "name.h"
 #include "xml.h"
 #include "xml_encoding.h"
 #include "reftypes.h"
-#include "endxmlin.h"
-#include "endin.h"
+#include "bibformats.h"
 
 typedef struct {
 	char *attrib;
 	char *internal;
 } attribs;
 
+extern variants end_all[];
+extern int end_nall;
+
+static int endxmlin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, str *line, str *reference, int *fcharset );
+static int endxmlin_processf( fields *endin, char *p, char *filename, long nref, param *pm );
+extern int endin_typef( fields *endin, char *filename, int nrefs, param *p );
+extern int endin_convertf( fields *endin, fields *info, int reftype, param *p );
+extern int endin_cleanf( bibl *bin, param *p );
+
+
+/*****************************************************
+ PUBLIC: void endxmlin_initparams()
+*****************************************************/
 void
 endxmlin_initparams( param *p, const char *progname )
 {
@@ -44,13 +57,17 @@ endxmlin_initparams( param *p, const char *progname )
 	p->all      = end_all;
 	p->nall     = end_nall;
 
-	list_init( &(p->asis) );
-	list_init( &(p->corps) );
+	slist_init( &(p->asis) );
+	slist_init( &(p->corps) );
 
 	if ( !progname ) p->progname = NULL;
 	else p->progname = strdup( progname );
 }
 
+/*****************************************************
+ PUBLIC: int endxmlin_readf()
+*****************************************************/
+
 static int
 xml_readmore( FILE *fp, char *buf, int bufsize, int *bufpos )
 {
@@ -58,14 +75,13 @@ xml_readmore( FILE *fp, char *buf, int bufsize, int *bufpos )
 	return 1;
 }
 
-int
-endxmlin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, newstr *line,
-	newstr *reference, int *fcharset )
+static int
+endxmlin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, str *line, str *reference, int *fcharset )
 {
-	newstr tmp;
+	str tmp;
 	char *startptr = NULL, *endptr = NULL;
 	int haveref = 0, inref = 0, done = 0, file_charset = CHARSET_UNKNOWN, m;
-	newstr_init( &tmp );
+	str_init( &tmp );
 	while ( !haveref && !done ) {
 		if ( line->data ) {
 			if ( !inref ) {
@@ -82,21 +98,21 @@ endxmlin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, newstr *line,
 				int n = 8;
 				char *p = &(line->data[line->len-1]);
 				while ( *p && n ) { p--; n--; }
-				newstr_segdel( line, line->data, p ); 
+				str_segdel( line, line->data, p );
 			}
 		}
 
 		if ( !startptr || !endptr ) {
 			done = xml_readmore( fp, buf, bufsize, bufpos );
-			newstr_strcat( line, buf );
+			str_strcatc( line, buf );
 		} else {
-			/* we can reallocate in the newstr_strcat, so re-find */
+			/* we can reallocate in the str_strcat, so re-find */
 			startptr = xml_findstart( line->data, "RECORD" );
 			endptr = xml_findend( line->data, "RECORD" );
-			newstr_segcpy( reference, startptr, endptr );
+			str_segcpy( reference, startptr, endptr );
 			/* clear out information in line */
-			newstr_strcpy( &tmp, endptr );
-			newstr_newstrcpy( line, &tmp );
+			str_strcpyc( &tmp, endptr );
+			str_strcpy( line, &tmp );
 			haveref = 1;
 		}
 		if ( line->data ) {
@@ -104,11 +120,15 @@ endxmlin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, newstr *line,
 			if ( m!=CHARSET_UNKNOWN ) file_charset = m;
 		}
 	}
-	newstr_free( &tmp );
+	str_free( &tmp );
 	*fcharset = file_charset;
 	return haveref;
 }
 
+/*****************************************************
+ PUBLIC: int endxmlin_processf()
+*****************************************************/
+
 /*
  * add data to fields
  */
@@ -126,26 +146,45 @@ endxmlin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, newstr *line,
  *          <style>aaa</style><style>aaaa</style>
  *   </datatype>
  */
-void
-endxmlin_datar( xml *node, newstr *s )
+static int
+endxmlin_datar( xml *node, str *s )
 {
-	if ( node->value && node->value->len )
-		newstr_strcat( s, node->value->data );
-	if ( node->down && xml_tagexact( node->down, "style" ) )
-		endxmlin_datar( node->down, s );
-	if ( xml_tagexact( node, "style" ) && node->next )
-		endxmlin_datar( node->next, s );
+	int status;
+
+	if ( str_has_value( node->value ) ) {
+		str_strcat( s, node->value );
+		if ( str_memerr( s ) ) return BIBL_ERR_MEMERR;
+	}
+	if ( node->down && xml_tagexact( node->down, "style" ) ) {
+		status = endxmlin_datar( node->down, s );
+		if ( status!=BIBL_OK ) return status;
+	}
+	if ( xml_tagexact( node, "style" ) && node->next ) {
+		status = endxmlin_datar( node->next, s );
+		if ( status!=BIBL_OK ) return status;
+	}
+
+	return BIBL_OK;
 }
 
-void
+static int
 endxmlin_data( xml *node, char *inttag, fields *info, int level )
 {
-	newstr s;
-	newstr_init( &s );
-	endxmlin_datar( node, &s );
-	if ( s.len )
-		fields_add( info, inttag, s.data, level );
-	newstr_free( &s );
+	int status;
+	str s;
+
+	str_init( &s );
+
+	status = endxmlin_datar( node, &s );
+	if ( status!=BIBL_OK ) return status;
+
+	if ( str_has_value( &s ) ) {
+		status = fields_add( info, inttag, s.data, level );
+		if ( status!=FIELDS_OK ) return BIBL_ERR_MEMERR;
+	}
+
+	str_free( &s );
+	return BIBL_OK;
 }
 
 /* <titles>
@@ -154,7 +193,7 @@ endxmlin_data( xml *node, char *inttag, fields *info, int level )
  *    </title>
  * </titles>
  */
-void
+static int
 endxmlin_titles( xml *node, fields *info )
 {
 	attribs a[] = {
@@ -164,18 +203,26 @@ endxmlin_titles( xml *node, fields *info )
 		{ "alt-title", "%!" },
 		{ "short-title", "SHORTTITLE" },
 	};
-	int i, n = sizeof( a ) / sizeof ( a[0] );
-	newstr title;
-	newstr_init( &title );
+	int i, status, n = sizeof( a ) / sizeof ( a[0] );
+	str title;
+	str_init( &title );
 	for ( i=0; i<n; ++i ) {
 		if ( xml_tagexact( node, a[i].attrib ) && node->down ) {
-			newstr_empty( &title );
-			endxmlin_datar( node, &title );
-			fields_add( info, a[i].internal, title.data, 0);
+			str_empty( &title );
+			status = endxmlin_datar( node, &title );
+			if ( status!=BIBL_OK ) return BIBL_ERR_MEMERR;
+			str_trimstartingws( &title );
+			str_trimendingws( &title );
+			status = fields_add( info, a[i].internal, title.data, 0);
+			if ( status!=FIELDS_OK ) return BIBL_ERR_MEMERR;
 		}
 	}
-	if ( node->next ) endxmlin_titles( node->next, info );
-	newstr_free( &title );
+	if ( node->next ) {
+		status = endxmlin_titles( node->next, info );
+		if ( status!=BIBL_OK ) return status;
+	}
+	str_free( &title );
+	return BIBL_OK;
 }
 
 /* <contributors>
@@ -199,65 +246,84 @@ endxmlin_titles( xml *node, fields *info )
  * >
  *
  */
-void
+static int
 endxmlin_contributor( xml *node, fields *info, char *int_tag, int level )
 {
-	endxmlin_data( node, int_tag, info, level );
-	if ( node->next )
-		endxmlin_contributor( node->next, info, int_tag, level );
+	int status;
+	status = endxmlin_data( node, int_tag, info, level );
+	if ( status!=BIBL_OK ) return status;
+	if ( node->next ) {
+		status = endxmlin_contributor( node->next, info, int_tag, level );
+		if ( status!=BIBL_OK ) return status;
+	}
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_contributors( xml *node, fields *info )
 {
-	attribs contrib[] = {
+	attribs a[] = {
 		{ "authors", "%A" },
 		{ "secondary-authors", "%E" },
 		{ "tertiary-authors", "%Y" },
 		{ "subsidiary-authors", "%?" },
 		{ "translated-authors", "%?" },
 	};
-	int i, n = sizeof( contrib ) / sizeof ( contrib[0] );
+	int i, status, n = sizeof( a ) / sizeof ( a[0] );
 	for ( i=0; i<n; ++i ) {
-		if ( xml_tagexact( node, contrib[i].attrib ) && node->down )
-			endxmlin_contributor( node->down, info, contrib[i].internal, 0 );
+		if ( xml_tagexact( node, a[i].attrib ) && node->down ) {
+			status = endxmlin_contributor( node->down, info, a[i].internal, 0 );
+			if ( status!=BIBL_OK ) return status;
+		}
 	}
-	if ( node->next )
-		endxmlin_contributors( node->next, info );
+	if ( node->next ) {
+		status = endxmlin_contributors( node->next, info );
+		if ( status!=BIBL_OK ) return status;
+	}
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_keyword( xml *node, fields *info )
 {
-	if ( xml_tagexact( node, "keyword" ) )
-		endxmlin_data( node, "%K", info, 0 );
-	if ( node->next )
-		endxmlin_keyword( node->next, info );
+	int status;
+	if ( xml_tagexact( node, "keyword" ) ) {
+		status = endxmlin_data( node, "%K", info, 0 );
+		if ( status!=BIBL_OK ) return status;
+	}
+	if ( node->next ) {
+		status = endxmlin_keyword( node->next, info );
+		if ( status!=BIBL_OK ) return status;
+	}
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_keywords( xml *node, fields *info )
 {
 	if ( node->down && xml_tagexact( node->down, "keyword" ) )
-		endxmlin_keyword( node->down, info );
+		return endxmlin_keyword( node->down, info );
+	return BIBL_OK;
 }
 
 /*
  *<electronic-resource-num><style face="normal" font="default" 
  * size="100%">10.1007/BF00356334</style></electronic-resource-num>
  */
-static void
+static int
 endxmlin_ern( xml *node, fields *info )
 {
 	if ( xml_tagexact( node, "electronic-resource-num" ) )
-		endxmlin_data( node, "DOI", info, 0 );
+		return endxmlin_data( node, "DOI", info, 0 );
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_language( xml *node, fields *info )
 {
 	if ( xml_tagexact( node, "language" ) )
-		endxmlin_data( node, "%G", info, 0 );
+		return endxmlin_data( node, "%G", info, 0 );
+	return BIBL_OK;
 }
 
 /*
@@ -267,139 +333,109 @@ endxmlin_language( xml *node, fields *info )
  *    </pdf-urls>
  * </urls>
  */
-static void
+static int
 endxmlin_fileattach( xml *node, fields *info )
 {
-	if ( xml_tagexact( node, "url" ) )
-		endxmlin_data( node, "FILEATTACH", info, 0 );
-	if ( node->down ) endxmlin_fileattach( node->down, info );
-	if ( node->next ) endxmlin_fileattach( node->next, info );
+	int status;
+	if ( xml_tagexact( node, "url" ) ) {
+		status = endxmlin_data( node, "FILEATTACH", info, 0 );
+		if ( status!=BIBL_OK ) return status;
+	}
+	if ( node->down ) {
+		status = endxmlin_fileattach( node->down, info );
+		if ( status!=BIBL_OK ) return status;
+	}
+	if ( node->next ) {
+		status = endxmlin_fileattach( node->next, info );
+		if ( status!=BIBL_OK ) return status;
+	}
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_urls( xml *node, fields *info )
 {
-	if ( xml_tagexact( node, "pdf-urls" ) && node->down )
-		endxmlin_fileattach( node->down, info );
-	else if ( xml_tagexact( node, "url" ) )
-		endxmlin_data( node, "%U", info, 0 );
-	else {
+	int status;
+	if ( xml_tagexact( node, "pdf-urls" ) && node->down ) {
+		status = endxmlin_fileattach( node->down, info );
+		if ( status!=BIBL_OK ) return status;
+	} else if ( xml_tagexact( node, "url" ) ) {
+		status = endxmlin_data( node, "%U", info, 0 );
+		if ( status!=BIBL_OK ) return status;
+	} else {
 		if ( node->down ) {
 			if ( xml_tagexact( node->down, "related-urls" ) ||
 			     xml_tagexact( node->down, "pdf-urls" ) ||
-			     xml_tagexact( node->down, "url" ) )
-				endxmlin_urls( node->down, info );
+			     xml_tagexact( node->down, "url" ) ) {
+				status = endxmlin_urls( node->down, info );
+				if ( status!=BIBL_OK ) return status;
+			}
 		}
 	}
-	if ( node->next )
-		endxmlin_urls( node->next, info );
+	if ( node->next ) {
+		status = endxmlin_urls( node->next, info );
+		if ( status!=BIBL_OK ) return status;
+	}
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_pubdates( xml *node, fields *info )
 {
 	if ( xml_tagexact( node, "date" ) )
-		endxmlin_data( node, "%8", info, 0 );
+		return endxmlin_data( node, "%8", info, 0 );
 	else {
 		if ( node->down && xml_tagexact( node->down, "date" ) )
-			endxmlin_pubdates( node->down, info );
+			return endxmlin_pubdates( node->down, info );
 	}
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_dates( xml *node, fields *info )
 {
-	if ( xml_tagexact( node, "year" ) )
-		endxmlin_data( node, "%D", info, 0 );
-	else {
+	int status;
+	if ( xml_tagexact( node, "year" ) ) {
+		status = endxmlin_data( node, "%D", info, 0 );
+		if ( status!=BIBL_OK ) return status;
+	} else {
 		if ( node->down ) {
-			if ( xml_tagexact( node->down, "year" ) )
-				endxmlin_dates( node->down, info );
-			if ( xml_tagexact( node->down, "pub-dates" ) )
-				endxmlin_pubdates( node->down, info );
+			if ( xml_tagexact( node->down, "year" ) ) {
+				status = endxmlin_dates( node->down, info );
+				if ( status!=BIBL_OK ) return status;
+			}
+			if ( xml_tagexact( node->down, "pub-dates" ) ) {
+				status = endxmlin_pubdates( node->down, info );
+				if ( status!=BIBL_OK );
+			}
 		}
 	}
-	if ( node->next )
-		endxmlin_dates( node->next, info );
-}
-
-#ifdef NOCOMPILE
-/*
- * There are a lot of elements in the end2xml stuff buried in element
- * attributes for which it's not clear where they should get stuck
- * -- for now put into notes
- */
-static void
-endxmlin_makeattribnotes( xml *node, fields *info, int level, attribs *a, int na )
-{
-	newstr *attrib, note;
-	int i;
-	newstr_init( &note );
-	for ( i=0; i<na; ++i ) {
-		attrib = xml_getattrib( node, a[i].attrib );
-		if ( attrib ) {
-			newstr_strcpy( &note, a[i].internal );
-			newstr_strcat( &note, ": " );
-			newstr_strcat( &note, attrib->data );
-			fields_add( info, "%O", note.data, level );
-			newstr_empty( &note );
-		}
+	if ( node->next ) {
+		status = endxmlin_dates( node->next, info );
+		if ( status!=BIBL_OK ) return status;
 	}
-	newstr_free( &note );
+	return BIBL_OK;
 }
-#endif
-
-#ifdef NOCOMPILE
-/* <!ELEMENT source-app (#PCDATA)>
- * <!ATTLIST source-app
- *        name CDATA #IMPLIED
- *        version CDATA #IMPLIED
- * >
- */
-static void
-endxmlin_sourceapp( xml *node, fields *info )
-{
-	attribs a[] = {
-		{ "name", "SOURCE APPLICATION NAME" },
-		{ "version", "SOURCE APPLICATION VERSION" }
-	};
-	int na = sizeof( a ) / sizeof( a[0] );
-	endxmlin_makeattribnotes( node, info, 0, a, na );
-}
-
-/* <!ELEMENT database (#PCDATA)>
- * <!ATTLIST database
- *        name CDATA #IMPLIED
- *        path CDATA #IMPLIED
- * >
- */
-static void
-endxmlin_database( xml *node, fields *info )
-{
-	attribs a[] = {
-		{ "name", "DATABASE NAME" },
-		{ "path", "DATABASE PATH" }
-	};
-	int na = sizeof( a ) / sizeof( a[0] );
-	endxmlin_makeattribnotes( node, info, 0, a, na );
-}
-#endif
 
 /*
  * <ref-type name="Journal Article">17</ref-type>
  */
-static void
+static int
 endxmlin_reftype( xml *node, fields *info )
 {
-	newstr *s;
+	int status;
+	str *s;
+
 	s = xml_getattrib( node, "name" );
-	if ( s && s->dim ) {
-		fields_add( info, "%0", s->data, 0 );
-		newstr_free( s );
+	if ( str_has_value( s ) ) {
+		status = fields_add( info, "%0", str_cstr( s ), 0 );
+		if ( status!=FIELDS_OK ) return BIBL_ERR_MEMERR;
 	}
+
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_record( xml *node, fields *info )
 {
 	attribs a[] = {
@@ -428,28 +464,35 @@ endxmlin_record( xml *node, fields *info )
 		{ "custom5", "%#" },
 		{ "custom6", "%$" },
 	};
-	int i, n = sizeof ( a ) / sizeof( a[0] );
+	int i, status, n = sizeof ( a ) / sizeof( a[0] );
 	if ( xml_tagexact( node, "DATABASE" ) ) {
-/*		endxmlin_database( node, info );*/
 	} else if ( xml_tagexact( node, "SOURCE-APP" ) ) {
-/*		endxmlin_sourceapp( node, info );*/
 	} else if ( xml_tagexact( node, "REC-NUMBER" ) ) {
 	} else if ( xml_tagexact( node, "ref-type" ) ) {
-		endxmlin_reftype( node, info );
+		status = endxmlin_reftype( node, info );
+		if ( status!=BIBL_OK ) return status;
 	} else if ( xml_tagexact( node, "contributors" ) ) {
-		if ( node->down ) endxmlin_contributors( node->down, info );
+		if ( node->down ) {
+			status = endxmlin_contributors( node->down, info );
+			if ( status!=BIBL_OK ) return status;
+		}
 	} else if ( xml_tagexact( node, "titles" ) ) {
 		if ( node->down ) endxmlin_titles( node->down, info );
 	} else if ( xml_tagexact( node, "keywords" ) ) {
-		endxmlin_keywords( node, info );
+		status = endxmlin_keywords( node, info );
+		if ( status!=BIBL_OK ) return status;
 	} else if ( xml_tagexact( node, "urls" ) ) {
-		endxmlin_urls( node, info );
+		status = endxmlin_urls( node, info );
+		if ( status!=BIBL_OK ) return status;
 	} else if ( xml_tagexact( node, "electronic-resource-num" ) ) {
-		endxmlin_ern( node, info );
+		status = endxmlin_ern( node, info );
+		if ( status!=BIBL_OK ) return status;
 	} else if ( xml_tagexact( node, "dates" ) ) {
-		endxmlin_dates( node, info );
+		status = endxmlin_dates( node, info );
+		if ( status!=BIBL_OK ) return status;
 	} else if ( xml_tagexact( node, "language" ) ) {
-		endxmlin_language( node, info );
+		status = endxmlin_language( node, info );
+		if ( status!=BIBL_OK ) return status;
 	} else if ( xml_tagexact( node, "periodical" ) ) {
 	} else if ( xml_tagexact( node, "secondary-volume" ) ) {
 	} else if ( xml_tagexact( node, "secondary-issue" ) ) {
@@ -478,22 +521,33 @@ endxmlin_record( xml *node, fields *info )
 	} else if ( xml_tagexact( node, "misc3" ) ) {
 	} else {
 		for ( i=0; i<n; ++i ) {
-			if ( xml_tagexact( node, a[i].attrib ) ) 
-				endxmlin_data( node, a[i].internal, info, 0 );
+			if ( xml_tagexact( node, a[i].attrib ) ) {
+				status = endxmlin_data( node, a[i].internal, info, 0 );
+				if ( status!=BIBL_OK ) return status;
+			}
 		}
 	}
-	if ( node->next ) endxmlin_record( node->next, info );
+	if ( node->next ) {
+		status = endxmlin_record( node->next, info );
+		if ( status!=BIBL_OK ) return status;
+	}
+	return BIBL_OK;
 }
 
-static void
+static int
 endxmlin_assembleref( xml *node, fields *info )
 {
-	if ( node->tag->len==0 ) {
-		if ( node->down ) endxmlin_assembleref( node->down, info );
-		return;
+	int status;
+	if ( str_is_empty( node->tag ) ) {
+		if ( node->down )
+			return endxmlin_assembleref( node->down, info );
 	} else if ( xml_tagexact( node, "RECORD" ) ) {
-		if ( node->down ) endxmlin_record( node->down, info );
+		if ( node->down ) {
+			status = endxmlin_record( node->down, info );
+			if ( status!=BIBL_OK ) return status;
+		}
 	}
+	return BIBL_OK;
 }
 
 /* endxmlin_processf first operates by converting to endnote input
@@ -502,13 +556,17 @@ endxmlin_assembleref( xml *node, fields *info )
  * this is necessary as the xml format is as nasty and as overloaded
  * as the tags used in the Refer format output
  */
-int
-endxmlin_processf( fields *fin, char *data, char *filename, long nref )
+static int
+endxmlin_processf( fields *fin, char *data, char *filename, long nref, param *pm )
 {
+	int status;
 	xml top;
+
 	xml_init( &top );
 	xml_tree( data, &top );
-	endxmlin_assembleref( &top, fin );
+	status = endxmlin_assembleref( &top, fin );
 	xml_free( &top );
-	return 1;
+
+	if ( status==BIBL_OK ) return 1;
+	return 0;
 }
