@@ -1,9 +1,10 @@
 /*
  * entities.c
  *
- * Copyright (c) Chris Putnam 2003-2009
+ * Copyright (c) Chris Putnam 2003-2017
+ *
+ * Source code released under the GPL version 2
  *
- * Source code released under the GPL
  */
 #include <stdio.h>
 #include <string.h>
@@ -21,7 +22,7 @@ entities html_entities[] = {
 	/* Special Entities */
 	{ "&quot;",     34 },  /* quotation mark */
 	{ "&amp;",      38 },  /* ampersand */
-	{ "&apos;",     39 },  /* apostrophe */
+	{ "&apos;",     39 },  /* apostrophe (note not defined in HTML) */
 	{ "&lpar;",     40 },  /* left parenthesis */
 	{ "&rpar;",     41 },  /* right parenthesis */
 	{ "&hyphen;",   45 },  /* hyphen */
@@ -316,7 +317,7 @@ decode_decimal_entity( char *s, unsigned int *pi, int *err )
 {
 	unsigned int c = 0, d;
 	int i = *pi, j = 2;
-	while ( isdigit( s[i+j] ) ) {
+	while ( isdigit( (unsigned char)s[i+j] ) ) {
 		d = s[i+j] - '0';
 		c = 10 * c + d;
 		j++;
@@ -337,9 +338,9 @@ decode_hex_entity( char *s, unsigned int *pi, int *err )
 {
 	unsigned int c = 0, d;
 	int i = *pi, j = 3;
-	while ( isxdigit( s[i+j] ) ) {
-		if ( isdigit( s[i+j] ) ) d = s[i+j]-'0';
-		else d = toupper(s[i+j])-'A' + 10;
+	while ( isxdigit( (unsigned char)s[i+j] ) ) {
+		if ( isdigit( (unsigned char)s[i+j] ) ) d = s[i+j]-'0';
+		else d = toupper((unsigned char)s[i+j])-'A' + 10;
 		c = 16 * c + d;
 		j++;
 	}
@@ -352,13 +353,16 @@ decode_hex_entity( char *s, unsigned int *pi, int *err )
  * decode numeric entity
  *
  *    extract a numeric entity from &#NNN; or &#xNNNN;
+ *
+ *    In XML, the "x" in hexadecimal entries should be lowercase,
+ *    but we'll be generous and accept "X" as well.
  */
 static unsigned int
 decode_numeric_entity( char *s, unsigned int *pi, int *err )
 {
 	unsigned int c;
 	*err = 0;
-	if ( s[*pi+2]!='x' ) c = decode_decimal_entity( s, pi, err );
+	if ( s[*pi+2]!='x' && s[*pi+2]!='X' ) c = decode_decimal_entity( s, pi, err );
 	else c = decode_hex_entity( s, pi, err );
 	if ( *err ) {
 		*pi = *pi + 1;
@@ -369,7 +373,12 @@ decode_numeric_entity( char *s, unsigned int *pi, int *err )
 
 /*
  * decode entity
- *    extract entity from  &xxxx; 
+ *    extract entity from  &mmmm;
+ *
+ * where &mmmm; is one of
+ * - &#nnnn; is code point in decimal form
+ * - &#xhhhh; is code point in hexadecimal form (note "x" is lowercase in XML)
+ * - &mmmm; corresponds to a pre-defined XML entity, e.g. &quote for quotations
  *
  */
 unsigned int
