@@ -1,12 +1,11 @@
 /*
  * isitypes.c
  *
- * Copyright (c) Chris Putnam 2004-2010
+ * Copyright (c) Chris Putnam 2004-2017
  *
- * Program and source code released under the GPL
+ * Program and source code released under the GPL version 2
  *
  */
-
 #include <stdio.h>
 #include <string.h>
 #include "is_ws.h"
@@ -25,19 +24,19 @@ static lookups article[] = {
 	{ "C1",     "ADDRESS",   SIMPLE, LEVEL_MAIN }, /* author address */
 	{ "PA",     "ADDRESS",   SIMPLE, LEVEL_HOST }, /* publisher address */
 	{ "RP",     "REPRINTADDRESS", SIMPLE, LEVEL_MAIN },
-	{ "PY",     "PARTYEAR",  SIMPLE, LEVEL_MAIN },
-	{ "PD",     "PARTMONTH", SIMPLE, LEVEL_MAIN },
+	{ "PY",     "PARTDATE:YEAR",  SIMPLE, LEVEL_MAIN },
+	{ "PD",     "PARTDATE:MONTH", SIMPLE, LEVEL_MAIN },
 	{ "VL",     "VOLUME",    SIMPLE, LEVEL_MAIN },
 	{ "AR",     "ARTICLENUMBER", SIMPLE, LEVEL_MAIN }, /* AR=article number that Phys. Rev. B uses instead of page numbers */
-	{ "BP",     "PAGESTART", SIMPLE, LEVEL_MAIN },
-	{ "EP",     "PAGEEND",   SIMPLE, LEVEL_MAIN },
-	{ "PG",     "TOTALPAGES", SIMPLE, LEVEL_MAIN },
+	{ "BP",     "PAGES:START", SIMPLE, LEVEL_MAIN },
+	{ "EP",     "PAGES:STOP",   SIMPLE, LEVEL_MAIN },
+	{ "PG",     "PAGES:TOTAL", SIMPLE, LEVEL_MAIN },
 	{ "IS",     "ISSUE",     SIMPLE, LEVEL_MAIN },
 	{ "SN",     "SERIALNUMBER", SERIALNO, LEVEL_HOST },
 	{ "AB",     "ABSTRACT",  SIMPLE, LEVEL_MAIN },
-	{ "NF",     "NOTES",     SIMPLE, LEVEL_MAIN },
-	{ "DE",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* author keywords */
-	{ "ID",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
+	{ "NF",     "NOTES",     NOTES,  LEVEL_MAIN },
+	{ "DE",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* author keywords */
+	{ "ID",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
 	{ "LA",     "LANGUAGE",  SIMPLE, LEVEL_MAIN },
 	{ "TC",     "TIMESCITED", SIMPLE, LEVEL_MAIN },
 	{ "NR",     "NUMBERREFS", SIMPLE, LEVEL_MAIN },
@@ -51,6 +50,7 @@ static lookups article[] = {
 	{ " ",      "INTERNAL_TYPE|ARTICLE",           ALWAYS, LEVEL_MAIN },
 	{ " ",      "ISSUANCE|continuing",    ALWAYS, LEVEL_HOST },
 	{ " ",      "RESOURCE|text",          ALWAYS, LEVEL_MAIN },
+	{ " ",      "GENRE|journal article",  ALWAYS, LEVEL_MAIN },
 	{ " ",      "GENRE|periodical",       ALWAYS, LEVEL_HOST },
 	{ " ",      "GENRE|academic journal", ALWAYS, LEVEL_HOST }
 };
@@ -67,18 +67,18 @@ static lookups book[] = {
 	{ "C1",     "ADDRESS",   SIMPLE, LEVEL_MAIN }, /* author address */
 	{ "PA",     "ADDRESS",   SIMPLE, LEVEL_MAIN }, /* publisher address */
 	{ "RP",     "REPRINTADDRESS", SIMPLE, LEVEL_MAIN },
-	{ "PY",     "YEAR",      SIMPLE, LEVEL_MAIN },
-	{ "PD",     "MONTH",     SIMPLE, LEVEL_MAIN },
+	{ "PY",     "DATE:YEAR",      SIMPLE, LEVEL_MAIN },
+	{ "PD",     "DATE:MONTH",     SIMPLE, LEVEL_MAIN },
 	{ "VL",     "VOLUME",    SIMPLE, LEVEL_MAIN },
-	{ "BP",     "PAGESTART", SIMPLE, LEVEL_MAIN },
-	{ "EP",     "PAGEEND",   SIMPLE, LEVEL_MAIN },
-	{ "PG",     "TOTALPAGES", SIMPLE, LEVEL_MAIN },
-	{ "IS",     "ISSUE",     SIMPLE, LEVEL_MAIN },
+	{ "BP",     "PAGES:START", SIMPLE, LEVEL_MAIN },
+	{ "EP",     "PAGES:STOP",  SIMPLE, LEVEL_MAIN },
+	{ "PG",     "PAGES:TOTAL", SIMPLE, LEVEL_MAIN },
+	{ "IS",     "ISSUE",       SIMPLE, LEVEL_MAIN },
 	{ "SN",     "SERIALNUMBER", SERIALNO, LEVEL_HOST },
 	{ "AB",     "ABSTRACT",  SIMPLE, LEVEL_MAIN },
-	{ "NF",     "NOTES",     SIMPLE, LEVEL_MAIN },
-	{ "DE",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* author keywords */
-	{ "ID",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
+	{ "NF",     "NOTES",     NOTES,  LEVEL_MAIN },
+	{ "DE",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* author keywords */
+	{ "ID",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
 	{ "LA",     "LANGUAGE",  SIMPLE, LEVEL_MAIN },
 	{ "TC",     "TIMESCITED", SIMPLE, LEVEL_MAIN },
 	{ "NR",     "NUMBERREFS", SIMPLE, LEVEL_MAIN },
@@ -108,18 +108,18 @@ static lookups inbook[] = {
 	{ "C1",     "ADDRESS",   SIMPLE, LEVEL_MAIN }, /* author address */
 	{ "PA",     "ADDRESS",   SIMPLE, LEVEL_HOST }, /* publisher address */
 	{ "RP",     "REPRINTADDRESS", SIMPLE, LEVEL_MAIN },
-	{ "PY",     "PARTYEAR",  SIMPLE, LEVEL_MAIN },
-	{ "PD",     "PARTMONTH", SIMPLE, LEVEL_MAIN },
+	{ "PY",     "PARTDATE:YEAR",  SIMPLE, LEVEL_MAIN },
+	{ "PD",     "PARTDATE:MONTH", SIMPLE, LEVEL_MAIN },
 	{ "VL",     "VOLUME",    SIMPLE, LEVEL_MAIN },
-	{ "BP",     "PAGESTART", SIMPLE, LEVEL_MAIN },
-	{ "EP",     "PAGEEND",   SIMPLE, LEVEL_MAIN },
-	{ "PG",     "TOTALPAGES", SIMPLE, LEVEL_HOST },
-	{ "IS",     "ISSUE",     SIMPLE, LEVEL_MAIN },
+	{ "BP",     "PAGES:START", SIMPLE, LEVEL_MAIN },
+	{ "EP",     "PAGES:STOP",  SIMPLE, LEVEL_MAIN },
+	{ "PG",     "PAGES:TOTAL", SIMPLE, LEVEL_HOST },
+	{ "IS",     "ISSUE",       SIMPLE, LEVEL_MAIN },
 	{ "SN",     "SERIALNUMBER", SERIALNO, LEVEL_HOST },
 	{ "AB",     "ABSTRACT",  SIMPLE, LEVEL_MAIN },
-	{ "NF",     "NOTES",     SIMPLE, LEVEL_MAIN },
-	{ "DE",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* author keywords */
-	{ "ID",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
+	{ "NF",     "NOTES",     NOTES,  LEVEL_MAIN },
+	{ "DE",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* author keywords */
+	{ "ID",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
 	{ "LA",     "LANGUAGE",  SIMPLE, LEVEL_MAIN },
 	{ "TC",     "TIMESCITED", SIMPLE, LEVEL_MAIN },
 	{ "NR",     "NUMBERREFS", SIMPLE, LEVEL_MAIN },
@@ -129,10 +129,11 @@ static lookups inbook[] = {
 	{ "GA",     "ISIDELIVERNUM", SIMPLE, LEVEL_MAIN}, /*ISI document delivery number */
 	{ "UT",     "ISIREFNUM", SIMPLE, LEVEL_MAIN }, /* ISI unique article identifer */
 	{ "DI",     "DOI",       SIMPLE, LEVEL_MAIN },
-	{ " ",      "INTERNAL_TYPE|INBOOK",   ALWAYS, LEVEL_MAIN },
-	{ " ",      "RESOURCE|text", ALWAYS, LEVEL_MAIN },
-	{ " ",      "ISSUANCE|monographic",    ALWAYS, LEVEL_HOST },
-	{ " ",      "GENRE|book",    ALWAYS, LEVEL_HOST }
+	{ " ",      "INTERNAL_TYPE|INBOOK", ALWAYS, LEVEL_MAIN },
+	{ " ",      "RESOURCE|text",        ALWAYS, LEVEL_MAIN },
+	{ " ",      "ISSUANCE|monographic", ALWAYS, LEVEL_HOST },
+        { " ",      "GENRE|book chapter",   ALWAYS, LEVEL_MAIN },
+	{ " ",      "GENRE|book",           ALWAYS, LEVEL_HOST }
 };
 
 static lookups bookinseries[] = {
@@ -149,18 +150,18 @@ static lookups bookinseries[] = {
 	{ "C1",     "ADDRESS",   SIMPLE, LEVEL_MAIN }, /* author address */
 	{ "PA",     "ADDRESS",   SIMPLE, LEVEL_HOST }, /* publisher address */
 	{ "RP",     "REPRINTADDRESS", SIMPLE, LEVEL_MAIN },
-	{ "PY",     "PARTYEAR",  SIMPLE, LEVEL_MAIN },
-	{ "PD",     "PARTMONTH", SIMPLE, LEVEL_MAIN },
+	{ "PY",     "PARTDATE:YEAR",  SIMPLE, LEVEL_MAIN },
+	{ "PD",     "PARTDATE:MONTH", SIMPLE, LEVEL_MAIN },
 	{ "VL",     "VOLUME",    SIMPLE, LEVEL_MAIN },
-	{ "BP",     "PAGESTART", SIMPLE, LEVEL_MAIN },
-	{ "EP",     "PAGEEND",   SIMPLE, LEVEL_MAIN },
-	{ "PG",     "TOTALPAGES", SIMPLE, LEVEL_MAIN },
+	{ "BP",     "PAGES:START", SIMPLE, LEVEL_MAIN },
+	{ "EP",     "PAGES:STOP",  SIMPLE, LEVEL_MAIN },
+	{ "PG",     "PAGES:TOTAL", SIMPLE, LEVEL_MAIN },
 	{ "IS",     "ISSUE",     SIMPLE, LEVEL_MAIN },
 	{ "SN",     "SERIALNUMBER", SERIALNO, LEVEL_HOST },
 	{ "AB",     "ABSTRACT",  SIMPLE, LEVEL_MAIN },
-	{ "NF",     "NOTES",     SIMPLE, LEVEL_MAIN },
-	{ "DE",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* author keywords */
-	{ "ID",     "KEYWORD",   ISI_KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
+	{ "NF",     "NOTES",     NOTES,  LEVEL_MAIN },
+	{ "DE",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* author keywords */
+	{ "ID",     "KEYWORD",   KEYWORD, LEVEL_MAIN }, /* new ISI keywords */
 	{ "LA",     "LANGUAGE",  SIMPLE, LEVEL_MAIN },
 	{ "TC",     "TIMESCITED", SIMPLE, LEVEL_MAIN },
 	{ "NR",     "NUMBERREFS", SIMPLE, LEVEL_MAIN },
