@@ -1,12 +1,13 @@
 /*
  * utf8.c
  *
- * Copyright (c) Chris Putnam 2004-2010
+ * Copyright (c) Chris Putnam 2004-2017
  *
- * Source code released under the GPL
+ * Source code released under the GPL version 2
  *
  */
 #include <stdio.h>
+#include <string.h>
 #include "utf8.h"
 
 /* UTF-8 encoding
@@ -79,6 +80,18 @@ utf8_encode( unsigned int value, unsigned char out[6] )
 	}
 }
 
+/* Generate UTF8 character as null-terminated string */
+void
+utf8_encode_str( unsigned int value, char outstr[7] )
+{
+	unsigned char encoded[6];
+	int i, n;
+	n = utf8_encode( value, encoded );
+	for ( i=0; i<n; ++i )
+		outstr[i] = ( char ) encoded[i];
+	outstr[n] = '\0';
+}
+
 unsigned int
 utf8_decode( char *s, unsigned int *pi )
 {
@@ -136,3 +149,40 @@ utf8_writebom( FILE *outptr )
 		fprintf(outptr,"%c",code[i]);
 }
 
+int
+utf8_is_bom( char *p )
+{
+	unsigned char *up = ( unsigned char * ) p;
+
+	/* ...if null-terminated string is too short, we're ok */
+	if ( up[0]!=0xEF ) return 0;
+	if ( up[1]!=0xBB ) return 0;
+	if ( up[2]!=0xBF ) return 0;
+
+	return 1;
+}
+
+/* utf8_is_emdash()
+ *
+ *emdash = 0xE2 (-30) 0x80 (-128) 0x94 (-108)
+ */
+int
+utf8_is_emdash( char *p )
+{
+	const char emdash[3] = { -30, -128, -108 };
+	if ( strncmp( p, emdash, 3 ) ) return 0;
+	return 1;
+}
+
+/* utf8_is_endash()
+ *
+ * endash = 0xE2 (-30) 0x80 (-128) 0x93 (-109)
+ */
+int
+utf8_is_endash( char *p )
+{
+	const char endash[3] = { -30, -128, -109 };
+	if ( strncmp( p, endash, 3 ) ) return 0;
+	return 1;
+}
+
