@@ -1,33 +1,40 @@
 /*
  * xml_getencoding.c
  *
- * Copyright (c) Chris Putnam 2007-2009
+ * Copyright (c) Chris Putnam 2007-2017
  *
- * Source code released under the GPL
+ * Source code released under the GPL version 2
  *
  */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "newstr.h"
-#include "newstr_conv.h"
+#include "charsets.h"
+#include "str.h"
+#include "str_conv.h"
 #include "xml.h"
 #include "xml_encoding.h"
 
 static int
 xml_getencodingr( xml *node )
 {
-	newstr *s;
 	int n = CHARSET_UNKNOWN, m;
+	str *s;
+	char *t;
+
 	if ( xml_tagexact( node, "xml" ) ) {
 		s = xml_getattrib( node, "encoding" );
-		if ( s && s->data ) {
-			if ( !strcasecmp( s->data, "UTF-8" ) ) 
+		if ( str_has_value( s ) ) {
+			t = str_cstr( s );
+			if ( !strcasecmp( t, "UTF-8" ) )
 				n = CHARSET_UNICODE;
-			else n = get_charset( s->data );
+			else if ( !strcasecmp( t, "UTF8" ) )
+				n = CHARSET_UNICODE;
+			else if ( !strcasecmp( t, "GB18030" ) )
+				n = CHARSET_GB18030;
+			else n = charset_find( t );
 			if ( n==CHARSET_UNKNOWN ) {
-				fprintf( stderr, "Warning: did not recognize "
-					"encoding '%s'\n", s->data );
+				fprintf( stderr, "Warning: did not recognize encoding '%s'\n", t );
 			}
 		}
 	}
@@ -39,29 +46,31 @@ xml_getencodingr( xml *node )
 		m = xml_getencodingr( node->next );
 		if ( m!=CHARSET_UNKNOWN ) n = m;
 	}
+
 	return n;
 }
 
 int
-xml_getencoding( newstr *s )
+xml_getencoding( str *s )
 {
-	newstr descriptor;
-	xml descriptxml;
 	int file_charset = CHARSET_UNKNOWN;
+	str descriptor;
+	xml descriptxml;
 	char *p, *q;
-	p = strstr( s->data, "<?xml" );
-	if ( !p ) p = strstr( s->data, "<?XML" );
+
+	p = strstr( str_cstr( s ), "<?xml" );
+	if ( !p ) p = strstr( str_cstr( s ), "<?XML" );
 	if ( p ) {
 		q = strstr( p, "?>" );
 		if ( q ) {
-			newstr_init( &descriptor );
-			newstr_segcpy( &descriptor, p, q+2 );
+			str_init( &descriptor );
+			str_segcpy( &descriptor, p, q+2 );
 			xml_init( &descriptxml );
-			xml_tree( descriptor.data, &descriptxml );
+			xml_tree( str_cstr( &descriptor ), &descriptxml );
 			file_charset = xml_getencodingr( &descriptxml );
 			xml_free( &descriptxml );
-			newstr_free( &descriptor );
-			newstr_segdel( s, p, q+2 );
+			str_free( &descriptor );
+			str_segdel( s, p, q+2 );
 		}
 	}
 	return file_charset;
